﻿using Bunny.Common.Exception;
using Bunny.Dao.Model.Constant;
using Bunny.Dao.Model.Result;
using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.Filters;
using Microsoft.Extensions.Logging;

namespace Bunny.Common.Filter;

/// <summary>
///     全局异常处理器
/// </summary>
/// <param name="logger"></param>
public class GlobalExceptionFilter(ILogger<GlobalExceptionFilter> logger) : IExceptionFilter
{
    public void OnException(ExceptionContext context)
    {
        // 错误的消息
        var message = context.Exception.Message;


        // 异常返回结果包装 也可以自定自定义返回类型
        var result = Result<string>.Error(ExceptionConstant.ServerError);

        // 如果是自己自定义的异常
        if (context.Exception is BunnyException)
        {
            var contextException = (BunnyException)context.Exception;
            message = contextException.Message;
            result = Result<string>.Error(contextException.Code, message);
        }

        // 日志记录
        logger.LogError(context.Exception, message);

        // 重新复写返回结果
        context.Result = new ObjectResult(result);
        context.ExceptionHandled = true;
    }
}