﻿using System.Net;
using Bunny.Common.Utils.Jwt;
using Bunny.Common.Utils.Net;
using Bunny.Dao.Model.Constant;
using Bunny.Dao.Vo.User;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc.Filters;
using Microsoft.IdentityModel.Tokens;

namespace Bunny.Service.Filter;

/// <summary>
///     自定义权限过滤器
/// </summary>
public class AuthorizationFilter : IAuthorizationFilter
{
    private string? _ipAddress;
    private HttpRequest? _request;
    private string? _requestPath;
    private string? _token;

    public void OnAuthorization(AuthorizationFilterContext context)
    {
        PathIgnore();
        var request = context.HttpContext.Request;
        _request = context.HttpContext.Request;
        _token = NetUtil.GetToken(request);
        _requestPath = NetUtil.GetRequestPath(request);
        _ipAddress = NetUtil.GetRequestIpAddress(request.HttpContext);

        // 是否匹配当前路径
        var matchPath = NetUtil.MatchPath(_requestPath);

        // 不匹配直接返回
        if (!matchPath) return;

        // 检查token
        CheckToken(context);

        // token 不为空
        if (_token == null) return;

        var jsonToObject = JwtUtil.ParseJwtToObject<LoginVo>(_token);
        // 打印日志
        Console.WriteLine(jsonToObject);
    }

    /// <summary>
    ///     检查token相关内容
    /// </summary>
    /// <param name="context">上下文对象</param>
    private void CheckToken(AuthorizationFilterContext context)
    {
        // token为空直接返回
        if (_token.IsNullOrEmpty() && _token == null)
        {
            Console.Error.WriteLine($"未授权登录访问：{_ipAddress}");
            context.Result = NetUtil.Out(HttpStatusCode.Unauthorized, ExceptionConstant.UserNotLoginException);
            return;
        }

        var loginVo = JwtUtil.ParseJwtToObject<LoginVo>(_token!);
        // 验证token是否过期
        if (!JwtUtil.IsJwtExpired(_token) && loginVo != null) return;
        Console.Error.WriteLine($"登录过期！用户Id：{loginVo!.Id},用户邮箱：{loginVo.Email}请求IP：{_ipAddress}");
        context.Result = NetUtil.Out(HttpStatusCode.Unauthorized, ExceptionConstant.UserTokenOutOfDateException);
    }

    /// <summary>
    ///     忽略匹配路径
    /// </summary>
    private static void PathIgnore()
    {
        var list = new List<string> { "/", "/api/**" };
        NetUtil.Ignores.AddRange(list);
    }
}