﻿using Bunny.Dao.Dto.System;
using Bunny.Dao.Entity.System;
using Bunny.Dao.Model.Result;
using Bunny.Service.IService;
using Microsoft.AspNetCore.Components;
using Microsoft.AspNetCore.Mvc;

namespace Bunny.WebApi.Controllers;

/// <summary>
///     BLog相关接口
/// </summary>
[Microsoft.AspNetCore.Mvc.Route("/api/[controller]/[action]")]
public class BlogController : ControllerBase
{
    [Inject] public required IBlogService BlogService { get; set; }

    /// <summary>
    ///     添加Blog
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    [HttpPost]
    public Result<object> AddBlog(Blog dto)
    {
        BlogService.AddBlog(dto);
        return Result<object>.Success();
    }

    /// <summary>
    ///     查询BLog
    /// </summary>
    /// <returns></returns>
    [HttpGet]
    public Result<List<Blog>> QueryBlog()
    {
        var vo = BlogService.QueryBlog();
        return Result<List<Blog>>.Success(vo);
    }

    /// <summary>
    ///     更新Blog内容
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    [HttpPost]
    public Result<object> UpdateBlog(BlogUpdateDto dto)
    {
        BlogService.UpdateBlog(dto);
        return Result<object>.Success();
    }

    /// <summary>
    ///     删除BLog
    /// </summary>
    /// <returns></returns>
    [HttpDelete]
    public Result<string> DeleteBlog(string id)
    {
        BlogService.DeleteBlog(id);
        return Result<string>.Success();
    }

    /// <summary>
    ///     批量添加数据
    /// </summary>
    /// <returns></returns>
    [HttpPost]
    public Result<string> AddBatchBlogs(string url)
    {
        BlogService.AddBatchBlogs(url);
        return Result<string>.Success();
    }

    /// <summary>
    ///     批量删除BLog
    /// </summary>
    /// <returns></returns>
    [HttpGet]
    public Result<string> DeleteBatchBlogs()
    {
        BlogService.DeleteBatchBlogs();
        return Result<string>.Success();
    }

    /// <summary>
    ///     批量更新_带事务
    /// </summary>
    /// <returns></returns>
    [HttpGet]
    public Result<string> UseTransaction()
    {
        BlogService.UseTransaction();
        return Result<string>.Success();
    }

    /// <summary>
    ///     分页查询
    /// </summary>
    /// <returns></returns>
    [HttpPost]
    public Result<PageResult<Blog>> QueryPage(int page = 1, int limit = 10)
    {
        var vo = BlogService.QueryPage(page, limit);

        return Result<PageResult<Blog>>.Success(vo);
    }
}