﻿using Bunny.Dao.Model.Result;
using Bunny.Service.IService;
using Microsoft.AspNetCore.Components;
using Microsoft.AspNetCore.Mvc;
using Minio.DataModel;
using Minio.DataModel.Result;

namespace Bunny.WebApi.Controllers;

[Microsoft.AspNetCore.Mvc.Route("/api/[controller]/[action]")]
[ApiController]
public class MinioController : ControllerBase
{
    [Inject] public required IMinioService MinioService { get; set; }

    /// <summary>
    ///     查询所有的桶
    /// </summary>
    /// <returns></returns>
    [HttpGet]
    public Result<ListAllMyBucketsResult> GetAllMyBuckets()
    {
        var listAllMyBucketsResult = MinioService.GetAllMyBuckets();
        return Result<ListAllMyBucketsResult>.Success(listAllMyBucketsResult);
    }

    /// <summary>
    ///     上传文件
    /// </summary>
    /// <param name="file">文件</param>
    /// <param name="filepath"></param>
    [HttpPost]
    public Result<string> SaveMinioFile(IFormFile? file, string filepath = "test")
    {
        MinioService.SaveMinioFile(file, filepath);
        return Result<string>.Success("上传成功");
    }

    /// <summary>
    ///     获取文件信息
    /// </summary>
    /// <param name="filename">文件名</param>
    /// <param name="bucketName">桶名称</param>
    /// <returns>ObjectStat</returns>
    [HttpGet]
    public Result<ObjectStat> GetObjectStat(string filename, string bucketName = "csharp-test")
    {
        var vo = MinioService.GetObjectStat(filename, bucketName);
        return Result<ObjectStat>.Success(vo);
    }

    /// <summary>
    ///     获取文件路径
    /// </summary>
    /// <param name="filename">文件名</param>
    /// <param name="bucketName">桶名称</param>
    /// <returns>文件地址</returns>
    [HttpGet]
    public Result<string> GetObjectPath(string filename, string bucketName = "csharp-test")
    {
        var vo = MinioService.GetObjectPath(filename, bucketName);
        return Result<string>.Success(vo);
    }

    /// <summary>
    ///     下载文件
    /// </summary>
    /// <param name="filename">文件名</param>
    /// <param name="bucketName">桶名称</param>
    /// <returns>下载文件</returns>
    [HttpGet]
    public IActionResult DownloadObject(string filename, string bucketName = "csharp-test")
    {
        var buffer = MinioService.DownloadObject(filename, bucketName).Result;
        return File(buffer, "application/octet-stream", filename);
    }

    /// <summary>
    ///     查看对象文件展示在网页中
    /// </summary>
    /// <param name="filename">文件名</param>
    /// <param name="bucketName">桶名称</param>
    /// <returns>下载文件</returns>
    [HttpGet]
    public IActionResult ViewObject(string filename, string bucketName = "csharp-test")
    {
        var buffer = MinioService.DownloadObject(filename, bucketName).Result;
        return File(buffer, "image/jpeg");
    }

    /// <summary>
    ///     列出文件夹下所有文件
    /// </summary>
    /// <param name="filepath">文件夹</param>
    /// <param name="bucketName">桶名称</param>
    /// <returns>所有文件</returns>
    [HttpGet]
    public Result<IAsyncEnumerable<Item>> ListObject(string? filepath, string bucketName = "csharp-test")
    {
        var vo = MinioService.ListObject(filepath, bucketName);
        return Result<IAsyncEnumerable<Item>>.Success(vo);
    }
}